@@ -1,5 +1,5 @@
 #
-# $Id: Perl6.pm 26593 2009-05-01 09:20:11Z azawawi $
+# $Id: Perl6.pm 26682 2009-05-05 17:13:03Z azawawi $
 #
 package Syntax::Highlight::Perl6;
 
@@ -24,7 +24,7 @@ use STD;
 
 # exports and version
 our @EXPORT_OK = qw();
-our $VERSION = '0.50';
+our $VERSION = '0.51';
 
 # filename constants
 Readonly my $FILE_CSS    => 'p6_style.css';
@@ -55,6 +55,7 @@ sub new {
     $options{resource_url} = $options{resource_url} // q{};
     $options{page_title} = $options{page_title} // q{};
     $options{utf8_decode} = $options{utf8_decode} // 1;
+    $options{tmp_prefix} = $options{tmp_prefix} // q{};
 
     #is 'text' undefined?
     if(! defined $options{text}) {
@@ -94,7 +95,8 @@ sub _lazy_parse {
         $self->{parser} = STD->parse(
             $src_text, 
             rule => $self->{rule},
-            actions => __PACKAGE__ . '::Actions'
+            actions => __PACKAGE__ . '::Actions',
+            tmp_prefix => $self->{tmp_prefix},
         );
 
         #we parsed it lazily...
@@ -641,6 +643,10 @@ HTML page title for C<simple_html> and C<full_html> (default: q{})
 
 Flag to enable/disable utf8 decoding. (default: 1 (Enabled))
 
+=item * tmp_prefix
+
+STD temporary files directory prefix. (default: q{})
+
 =back
 
 =head2 snippet_html
